@@ -23,6 +23,8 @@ from python_release_master.core.validation import (
 from python_release_master.core.logger import logger
 from python_release_master.core.errors import ErrorCode, ReleaseError
 from python_release_master.core.validation_manager import ValidationManager
+from python_release_master.core.version_manager import VersionManager
+from python_release_master.core.git import GitManager
 
 def create_github_repository(config: Config) -> None:
     """Create GitHub repository if it doesn't exist.
@@ -98,127 +100,79 @@ def create_github_repository(config: Config) -> None:
             cause=e
         )
 
-def create_release(config: Config, workspace_dir: Optional[Path] = None) -> None:
+def create_release(config: Config) -> None:
     """Create a new release.
     
     Args:
         config: Configuration object
-        workspace_dir: Optional workspace directory path
-    
+        
     Raises:
         ReleaseError: If release creation fails
     """
-    workspace_dir = Path(workspace_dir or os.getcwd())
-    
     try:
-        # Initialize validation manager
-        validator = ValidationManager(config, workspace_dir)
+        # Step 1: Validate environment
+        logger.start_operation("Validating environment...")
+        validation_manager = ValidationManager(config)
+        validation_manager.validate_environment()
         
-        # Step 1: Run all validation checks
-        validator.validate_all()
+        # Step 2: Analyze changes and suggest version bump
+        logger.start_operation("Analyzing changes...")
+        version_manager = VersionManager(Path.cwd())
+        current_version = version_manager.get_current_versions()["pyproject.toml"]
+        new_version = version_manager.suggest_version_bump("patch")  # Default to patch bump
         
-        # Step 2: Clean dist directory and validate build
-        logger.start_operation("Cleaning dist directory...")
-        clean_dist()
-        logger.success("Cleaned dist directory")
+        # Step 3: Generate changelog
+        logger.start_operation("Generating changelog...")
+        changelog_content = generate_changelog(config)
         
-        logger.start_operation("Validating package build...")
-        try:
-            cmd = ["uv", "build", "--no-sources"]
-            logger.command(cmd)
-            result = subprocess.run(cmd, check=True, capture_output=True, text=True)
-            logger.success("Package build validation passed")
-        except subprocess.CalledProcessError as e:
-            raise ReleaseError(
-                code=ErrorCode.BUILD_FAILED,
-                message=f"Package build validation failed:\n{e.stdout}\n{e.stderr}",
-                context={"command": " ".join(cmd), "exit_code": e.returncode}
+        # Step 4: Update version files
+        logger.start_operation("Updating version files...")
+        version_manager.bump_version(new_version)
+        
+        # Step 5: Build package
+        logger.start_operation("Building package...")
+        cmd = ["uv", "build", "--no-sources"]
+        logger.command(cmd)
+        subprocess.run(cmd, check=True, capture_output=True, text=True)
+        logger.success("Package built successfully")
+        
+        # Step 6: Create Git tag and release
+        logger.start_operation("Creating Git tag and release...")
+        git_manager = GitManager(Path.cwd())
+        
+        # Generate release title
+        title = generate_release_title(new_version, changelog_content)
+        
+        # Create tag and release
+        git_manager.create_tag(f"v{new_version}", title)
+        if config.git.push:
+            git_manager.push_changes(tags=True)
+        
+        if config.git.release.enabled:
+            git_manager.create_release(
+                tag=f"v{new_version}",
+                title=title,
+                description=changelog_content,
+                draft=config.git.release.draft,
+                prerelease=config.git.release.prerelease,
+                generate_notes=config.git.release.generate_notes
             )
         
-        # Step 3: Create GitHub repository if needed
-        create_github_repository(config)
-        
-        # Step 4: Analyze changes and determine version bump
-        logger.start_operation("Analyzing changes for version bump...")
-        logger.api_call("OpenAI", "chat/completions", {
-            "model": config.changelog.ai.model,
-            "temperature": config.changelog.ai.temperature,
-            "messages": [{"role": "system", "content": "Analyze git changes for version bump"}]
-        })
-        bump_type = analyze_changes_for_version_bump(
-            model=config.changelog.ai.model,
-            temperature=config.changelog.ai.temperature
-        )
-        logger.success(f"Determined version bump type: {bump_type}")
-        
-        # Step 5: Bump version
-        logger.start_operation("Bumping version...")
-        new_version = bump_version(bump_type)
-        logger.success(f"Bumped version to {new_version}")
-        
-        # Step 6: Generate changelog
-        logger.start_operation("Generating changelog...")
-        try:
-            if config.changelog.ai.enabled:
-                logger.api_call("OpenAI", "chat/completions", {
-                    "model": config.changelog.ai.model,
-                    "temperature": config.changelog.ai.temperature,
-                    "messages": [{"role": "system", "content": "Generate changelog"}]
-                })
-                changelog_text = generate_changelog_with_ai(
-                    model=config.changelog.ai.model,
-                    temperature=config.changelog.ai.temperature,
-                    sections=config.changelog.sections
-                )
-            else:
-                changelog_text = generate_changelog(config.changelog.sections, False)
-            logger.success("Generated changelog")
-        except Exception as e:
-            logger.warning(f"Error generating changelog: {e}")
-            logger.warning("Falling back to manual changelog generation")
-            changelog_text = generate_changelog(config.changelog.sections, False)
-        
-        # Step 7: Generate release title
-        logger.start_operation("Generating release title...")
-        title = generate_release_title(
-            new_version,
-            changelog_text,
-            model=config.changelog.ai.model,
-            temperature=config.changelog.ai.temperature,
-        )
-        logger.success(f"Generated release title: {title}")
-        
-        # Step 8: Build final package for publishing
-        if config.pypi.publish:
-            logger.start_operation("Building package for publishing...")
-            cmd = ["uv", "build", "--no-sources"]
-            logger.command(cmd)
-            result = subprocess.run(cmd, check=True, capture_output=True, text=True)
-            logger.success("Package built successfully")
-            
-            # Step 9: Publish to PyPI
-            logger.start_operation("Publishing package...")
-            publish_package(config)
-            logger.success("Package published to PyPI")
-        
-        # Step 10: Create Git release
-        if config.git.release.enabled:
-            logger.start_operation("Creating Git release...")
-            create_git_release(new_version, title, changelog_text, config)
-            logger.success("Git release created")
-        
-        # Final success message
-        logger.panel(
-            f"Successfully created release {new_version}\n\n"
-            f"Title: {title}\n\n"
-            f"Changelog:\n{changelog_text}",
-            "Release Complete",
-            "green"
-        )
+        logger.success(f"Successfully created release v{new_version}")
         
     except ReleaseError as e:
-        logger.error("Release creation failed")
-        raise e
+        logger.error(f"Release creation failed: {e.message}")
+        if e.fix_instructions:
+            for instruction in e.fix_instructions:
+                logger.error(f"- {instruction}")
+        raise
+    except Exception as e:
+        logger.error(f"Unexpected error during release: {str(e)}")
+        raise ReleaseError(
+            code=ErrorCode.UNKNOWN_ERROR,
+            message=f"Unexpected error during release: {str(e)}",
+            cause=e
+        )
 
 def publish_package(config: Config) -> None:
     """Publish package to PyPI using uv.
@@ -254,7 +208,7 @@ def publish_package(config: Config) -> None:
         # Check for metadata version issues
         if "metadata version" in error_output.lower():
             raise ReleaseError(
-                code=ErrorCode.PYPI_METADATA_ERROR,
+                code=ErrorCode.PYPI_VALIDATION_ERROR,
                 message=f"Failed to publish package due to metadata version incompatibility:\n{error_output}",
                 context={"command": " ".join(cmd), "exit_code": e.returncode}
             )
@@ -476,4 +430,19 @@ def create_git_release(version: str, title: str, description: str, config: Confi
             code=ErrorCode.GIT_RELEASE_FAILED,
             message=f"Failed to create Git release:\n{e.stdout}\n{e.stderr}",
             context={"command": " ".join(e.cmd), "exit_code": e.returncode}
-        )
\ No newline at end of file
+        )
+
+def analyze_changes() -> str:
+    """Analyze changes to determine version bump type.
+    
+    Returns:
+        Version bump type (major, minor, patch)
+    """
+    logger.start_operation("Analyzing changes for version bump...")
+    
+    # For now, default to patch
+    # TODO: Implement AI-powered analysis of changes
+    bump_type = "patch"
+    
+    logger.success(f"Determined version bump type: {bump_type}")
+    return bump_type
\ No newline at end of file
