@@ -352,6 +352,101 @@ class PyProjectValidator(BaseValidator):
                     ]
                 )
     
+    def _validate_build_includes(self, config: Dict[str, Any]) -> None:
+        """Validate build includes configuration.
+        
+        Args:
+            config: pyproject.toml configuration
+            
+        Raises:
+            ReleaseError: If validation fails
+        """
+        package_name = config["project"]["name"].replace("-", "_")
+        build_config = config.get("tool", {}).get("hatch", {}).get("build", {})
+        includes = build_config.get("include", [])
+        
+        required_includes = [
+            f"src/{package_name}/**/*.py",
+            f"src/{package_name}/**/*.pyi",
+        ]
+        
+        missing_includes = [inc for inc in required_includes if inc not in includes]
+        if missing_includes:
+            raise ReleaseError(
+                ErrorCode.CONFIG_MISSING_FIELD,
+                "Missing required build includes in pyproject.toml",
+                fix_instructions=[
+                    "Add the following includes to [tool.hatch.build] section:",
+                    "include = [",
+                    *[f'    "{inc}",' for inc in required_includes],
+                    "]",
+                    "",
+                    "Example configuration:",
+                    "[tool.hatch.build]",
+                    "include = [",
+                    f'    "src/{package_name}/**/*.py",',
+                    f'    "src/{package_name}/**/*.pyi",',
+                    "    # Add any other includes you need",
+                    "]",
+                    'packages = ["src"]'
+                ]
+            )
+
+    def _validate_entry_points(self, config: Dict[str, Any]) -> None:
+        """Validate entry points configuration.
+        
+        Args:
+            config: pyproject.toml configuration
+            
+        Raises:
+            ReleaseError: If validation fails
+        """
+        package_name = config["project"]["name"]
+        package_import = package_name.replace("-", "_")
+        scripts = config.get("project", {}).get("scripts", {})
+        
+        # Check if the main tool entry point exists and is correct
+        expected_entry = f"{package_import}.__main__:main"
+        actual_entry = scripts.get(package_name)
+        
+        if not actual_entry:
+            raise ReleaseError(
+                ErrorCode.CONFIG_MISSING_FIELD,
+                f"Missing required entry point for {package_name} in [project.scripts]",
+                fix_instructions=[
+                    "Add the following entry point to [project.scripts] section:",
+                    "[project.scripts]",
+                    f'{package_name} = "{expected_entry}"',
+                    "",
+                    "Then create the corresponding __main__.py file:",
+                    f"src/{package_import}/__main__.py",
+                    "",
+                    "Example __main__.py content:",
+                    "def main():",
+                    '    """Entry point for the CLI."""',
+                    "    # Your CLI code here",
+                    "    return 0",
+                    "",
+                    "if __name__ == '__main__':",
+                    "    main()"
+                ]
+            )
+        elif actual_entry != expected_entry:
+            raise ReleaseError(
+                ErrorCode.CONFIG_INVALID_VALUE,
+                f"Invalid entry point format for {package_name}",
+                fix_instructions=[
+                    "Update the entry point in [project.scripts] section:",
+                    "[project.scripts]",
+                    f'{package_name} = "{expected_entry}"  # Current: {actual_entry}',
+                    "",
+                    "The entry point should:",
+                    f"1. Use the package import name: {package_import}",
+                    "2. Point to __main__:main",
+                    "3. Have a corresponding __main__.py file with a main() function"
+                ]
+            )
+    
     def validate(self) -> None:
         """Validate pyproject.toml configuration.
         
@@ -414,6 +509,12 @@ class PyProjectValidator(BaseValidator):
         
         # Check metadata compatibility with build backend
         self._check_metadata_compatibility(config)
+        
+        # Validate build includes
+        self._validate_build_includes(config)
+        
+        # Validate entry points
+        self._validate_entry_points(config)
 
 
 class PackageStructureValidator(BaseValidator):
